#!/usr/bin/python

# Change the dome shutter azimuth by an angle 
#
# Copyright 2012 John Kielkopf
#
#
# Assumes DLI controller these connections --
#
#   1  Decrease Azimuth
#   2  Increase Azimuth
#   3  
#   4
#   5  Open Lower
#   6  Close Lower
#   7  Open Upper
#   8  Close Upper
# 
# Based on software from Dwight Hubbard d@dhub.me
#   provided as an example on the DLI website           

# CDK20N Sirius dome scans about 6 (24 degrees) tags in 10 seconds

import sys
import time
import math
import argparse

parser= argparse.ArgumentParser(description = ' Rotate the dome by an angle in degrees')
parser.add_argument('-a', type = float)

if len(sys.argv) == 1:
  sys.exit("Usage: change_azimuth.py angle (Signed angle as an argument)")
  exit()
elif len(sys.argv) == 2:
  delta_azimuth = float(sys.argv[1])
elif len(sys.argv) == 3:
  args = parser.parse_args()
  delta_azimuth = args.a
else:
  sys.exit("Usage: change_azimuth.py angle (Provide signed angle as an argument)")
  exit() 
 
if (delta_azimuth > 90.) or (delta_azimuth < -90.):
  print('Request exceeds 90 degree limit.  Use a smaller increment.')
  exit()


# The dli module needs to be in the python path.  
# Add current directory to the path so we can find the dli module

sys.path.append('.')

# Import the DLI module -- must be in the same directory as this py file

import dli


# Switch settings for the DLI device

#SWITCHIP="139.86.48.99"
#USER="user"
#PASSWORD="password"

SWITCHIP="139.86.48.99"
USER="admin"
PASSWORD="password"


# Open (connect) to the power switch, if the
# parameters are not passed it defaults to the
# IP address, user and password the switch is 
# set with from the factory.  Only changed items
# actually need to be passed.
switch=dli.powerswitch(hostname=SWITCHIP,userid=USER,password=PASSWORD)

# Verify the switch
if not switch.verify():
  print "Cannot talk to the switch"
  sys.exit(1)

# Print the current state of all the outlets
#switch.printstatus()
  
if (delta_azimuth > 0.):

# Power increase azimuth on
  switch.on(2)

# Print the switch state
  print 'Increase dome azimuth switch is  ',switch.status(2)

# Wait the dome to rotate the requested angle
  dps = 2.5
  delay = delta_azimuth/dps
  time.sleep(delay)

# Power increase dome azimuth off
  switch.off(2)

# Print the switch state again
  print 'Increase dome azimuth switch is  ',switch.status(2)

elif (delta_azimuth < 0.):

# Power decrease azimuth on
  switch.on(1)

# Print the switch state
  print 'Decrease dome azimuth switch is  ',switch.status(1)

# Wait the dome to rotate the requested angle
  dps = 2.5
  delay = -1.*delta_azimuth/dps
  time.sleep(delay)

# Power decrease dome azimuth off
  switch.off(1)

# Print the switch state again
  print 'Decrease dome azimuth switch is  ',switch.status(1)

else:
  print 'No rotation requested.'  
  
exit()
  
